@@ -251,7 +251,6 @@ static gboolean board_handle_arrow_event (GtkWidget *item,
   /* is currently an object moved? */
   if (anim_data->timeout_id != -1)
     return FALSE;
-
   if (event->type == GDK_BUTTON_PRESS && selector_data->selected) {
     selector_data->mouse_steering = TRUE;
     move_item (selector_data->sel_item, GPOINTER_TO_INT (direction));
@@ -318,16 +317,38 @@ static void create_logo (void)
 {
   GdkPixbuf *pixbuf;
   int tile_width, tile_height;
+  GtkWidget *logo_image;
+  GtkWidget *tips_label;
+  GtkCssProvider *provider;
+  GtkStyleContext *context;
 
   theme_get_tile_size (board_theme, &tile_width, &tile_height);
   pixbuf = gdk_pixbuf_new_from_file (DATADIR "/atomix/atomix-logo.png", NULL);
 
-  level_items->logo = gtk_image_new_from_pixbuf (pixbuf);
-  gtk_widget_show (level_items->logo);
-  gtk_fixed_put (GTK_FIXED (board_canvas), level_items->logo,
-                 BGR_FLOOR_COLS * tile_width/2 - gdk_pixbuf_get_width (pixbuf)/2,
-                 BGR_FLOOR_ROWS * tile_height/2 - gdk_pixbuf_get_height (pixbuf)/2);
+  level_items->logo = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
 
+  context = gtk_widget_get_style_context (level_items->logo);
+  provider = gtk_css_provider_new ();
+  gtk_css_provider_load_from_data (provider, "* {  background-color: rgba(230, 230, 230, 0.6); }", -1, NULL);
+  gtk_style_context_add_provider (context, GTK_STYLE_PROVIDER (provider), GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
+  logo_image = gtk_image_new_from_pixbuf (pixbuf);
+  gtk_widget_set_valign (logo_image, GTK_ALIGN_END);
+  gtk_box_pack_start (GTK_BOX (level_items->logo), logo_image, TRUE, TRUE, 12);
+
+  tips_label = gtk_label_new (_("Guide the atoms through the maze to form molecules. "
+                                "Click, or use the arrow keys and Enter, to select an atom and move it. "
+                                "Be careful, though: an atom keeps moving until it hits a wall."));
+  gtk_box_pack_start (GTK_BOX (level_items->logo), tips_label, TRUE, TRUE, 12);
+  gtk_widget_set_valign (tips_label, GTK_ALIGN_START);
+  gtk_widget_show_all (level_items->logo);
+
+  gtk_fixed_put (GTK_FIXED (board_canvas), level_items->logo,
+                 0, 0);
+  gtk_widget_set_size_request (level_items->logo, BGR_FLOOR_COLS * tile_width, BGR_FLOOR_ROWS * tile_height);
+  gtk_widget_set_size_request (GTK_WIDGET (tips_label), BGR_FLOOR_COLS * tile_width, -1);
+  gtk_label_set_justify (GTK_LABEL (tips_label), GTK_JUSTIFY_CENTER);
+  gtk_label_set_line_wrap (GTK_LABEL (tips_label), TRUE);
+  
   g_object_unref (pixbuf);
 }
 
@@ -487,9 +508,14 @@ static void render_tile (Tile *tile, gint row, gint col) {
   }
 }
 
+static void show_sensitive (GtkWidget *widget)
+{
+  gtk_widget_set_visible (widget, gtk_widget_is_sensitive (widget));
+}
+
 static gboolean show_arrow_group (SelectorData *data)
 {
-  g_slist_foreach (data->arrows, (GFunc)gtk_widget_show, NULL);
+  g_slist_foreach (data->arrows, (GFunc)show_sensitive, NULL);
   data->arrow_show_timeout = -1;
 
   return FALSE;
@@ -872,12 +898,10 @@ static void check_for_arrow (gint r, gint c, GtkWidget *arrow) {
 
   tile = playfield_get_tile (board_sce, r, c);
 
-  if (tile == NULL)
-    gtk_widget_show (arrow);
-  else {
-    gtk_widget_hide (arrow);
+  gtk_widget_set_sensitive (arrow, tile == NULL);
+
+  if (tile != NULL)
     g_object_unref (tile);
-  }
 }
 
 static void selector_arrows_show (SelectorData *data)
