@@ -67,50 +67,48 @@ static void calculate_score (void);
              Menu callback  functions 
 
 -------------------------------------------------------------- */
-static void verb_GameNew_cb (GtkMenuItem * action, gpointer data)
+static void verb_GameNew_cb (GSimpleAction *action, GVariant *variant, gpointer data)
 {
   controller_handle_action (GAME_ACTION_NEW);
 }
 
-static void verb_GameEnd_cb (GtkMenuItem * action, gpointer data)
+static void verb_GameEnd_cb (GSimpleAction *action, GVariant *variant, gpointer data)
 {
   controller_handle_action (GAME_ACTION_END);
 }
 
-static void verb_GameSkip_cb (GtkMenuItem * action, gpointer data)
+static void verb_GameSkip_cb (GSimpleAction *action, GVariant *variant, gpointer data)
 {
   controller_handle_action (GAME_ACTION_SKIP);
 }
 
-static void verb_GameReset_cb (GtkMenuItem * action, gpointer data)
+static void verb_GameReset_cb (GSimpleAction *action, GVariant *variant, gpointer data)
 {
   controller_handle_action (GAME_ACTION_RESTART);
 }
 
-static void verb_GamePause_cb (GtkMenuItem * action, gpointer data)
+static void verb_GamePause_cb (GSimpleAction *action, GVariant *variant, gpointer data)
 {
   controller_handle_action (GAME_ACTION_PAUSE);
 }
 
-static void verb_GameContinue_cb (GtkMenuItem * action, gpointer data)
+static void verb_GameContinue_cb (GSimpleAction *action, GVariant *variant, gpointer data)
 {
   controller_handle_action (GAME_ACTION_CONTINUE);
 }
 
-static void verb_GameUndo_cb (GtkMenuItem * action, gpointer data)
+static void verb_GameUndo_cb (GSimpleAction *action, GVariant *variant, gpointer data)
 {
   controller_handle_action (GAME_ACTION_UNDO);
 }
 
-static void verb_GameExit_cb (GtkMenuItem * action, gpointer data)
+static void verb_GameExit_cb (GSimpleAction *action, GVariant *variant, gpointer data)
 {
   atomix_exit ();
 }
 
-static void verb_HelpAbout_cb (GtkMenuItem * action, gpointer data)
+static void verb_HelpAbout_cb (GSimpleAction *action, GVariant *variant, gpointer data)
 {
-  GtkWidget *dlg;
-
   const char *authors[] =
     {
       "Robert Roth <robert.roth.off@gmail.com>",
@@ -125,17 +123,17 @@ static void verb_HelpAbout_cb (GtkMenuItem * action, gpointer data)
       NULL
     };
 
-  dlg = gtk_about_dialog_new ();
-  g_signal_connect (dlg, "response", G_CALLBACK (gtk_widget_destroy), NULL);
-  gtk_about_dialog_set_program_name (GTK_ABOUT_DIALOG(dlg), _("Atomix"));
-  gtk_about_dialog_set_version (GTK_ABOUT_DIALOG(dlg), VERSION);
-  gtk_about_dialog_set_comments (GTK_ABOUT_DIALOG(dlg), _("A puzzle game about atoms and molecules"));
-  gtk_about_dialog_set_website (GTK_ABOUT_DIALOG(dlg), "http://wiki.gnome.org/Apps/Atomix");
-  gtk_about_dialog_set_authors (GTK_ABOUT_DIALOG(dlg), authors);
-  gtk_about_dialog_set_artists (GTK_ABOUT_DIALOG(dlg), artists);
-  gtk_about_dialog_set_translator_credits (GTK_ABOUT_DIALOG(dlg), _("translator-credits"));
-  gtk_window_set_transient_for (GTK_WINDOW (dlg), GTK_WINDOW (app->mainwin));
-  gtk_widget_show (dlg);
+
+  gtk_show_about_dialog(GTK_WINDOW(app->mainwin),
+  					"program-name", _("Atomix"),
+					"logo-icon-name", "atomix",
+  					"version", VERSION,
+  					"comments", _("A puzzle game about atoms and molecules"),
+  					"website", "https://github.com/GNOME/atomix",
+  					"authors", authors,
+  					"artists", artists,
+  					"translator_credits", _("translator-credits"),
+  					NULL);
 }
 
 static gboolean on_app_destroy_event (GtkWidget *widget, GdkEvent *event,
@@ -360,13 +358,9 @@ static void atomix_exit (void)
   if (app->tm)
     g_object_unref (app->tm);
 
-  if (app->actions)
-    g_hash_table_destroy (app->actions);
-
   /* quit application */
   gtk_widget_destroy (app->mainwin);
 
-  gtk_main_quit ();
 }
 
 static gboolean on_key_press_event (GObject *widget, GdkEventKey *event,
@@ -498,6 +492,24 @@ typedef struct
   gboolean enabled;
 } CmdEnable;
 
+
+static const GActionEntry app_entries[] =
+  {
+    { "GameAbout", verb_HelpAbout_cb, NULL, NULL, NULL},
+    { "GameQuit", verb_GameExit_cb, NULL, NULL, NULL}
+  };
+
+static const GActionEntry win_entries[] =
+  {
+    { "GameNew", verb_GameNew_cb, NULL, NULL, NULL},
+    { "GameEnd", verb_GameEnd_cb, NULL, NULL, NULL},
+    { "GameSkip", verb_GameSkip_cb, NULL, NULL, NULL},
+    { "GameReset", verb_GameReset_cb, NULL, NULL, NULL},
+    { "GameUndo", verb_GameUndo_cb, NULL, NULL, NULL},
+    { "GamePause", verb_GamePause_cb, NULL, NULL, NULL},
+    { "GameContinue", verb_GameContinue_cb, NULL, NULL, NULL},
+  };
+
 static const CmdEnable not_running[] =
   {
     { "GameNew",      TRUE  },
@@ -555,12 +567,12 @@ void update_menu_item_state (void)
 {
   gint i;
   const CmdEnable *cmd_list = state_sensitivity[app->state];
-  GtkWidget *widget;
+  GAction *action;
 
   for (i = 0; cmd_list[i].cmd != NULL; i++)
     {
-      widget = g_hash_table_lookup (app->actions, cmd_list[i].cmd);
-      gtk_widget_set_sensitive (widget, cmd_list[i].enabled);
+      action = g_action_map_lookup_action (G_ACTION_MAP (app->mainwin), cmd_list[i].cmd);
+      g_simple_action_set_enabled (G_SIMPLE_ACTION (action), cmd_list[i].enabled);
     }
 }
 
@@ -569,67 +581,26 @@ void update_menu_item_state (void)
              GUI creation  functions 
 
 -------------------------------------------------------------- */
-static AtomixApp *create_gui (void)
+static AtomixApp *create_gui (GApplication *app_instance)
 {
   AtomixApp *app;
   gchar *ui_path;
-  gchar *icon_path;
   GtkBuilder *builder;
   GtkWidget *stats_grid;
   GtkWidget *time_label;
-  GtkWidget *menu_item;
 
   app = g_new0 (AtomixApp, 1);
   app->level = NULL;
+  app->app_instance = app_instance;
 
   builder = gtk_builder_new ();
-  
+
   ui_path = g_build_filename (PKGDATADIR, "ui", "interface.ui", NULL);
   gtk_builder_add_from_file (builder, ui_path, NULL);
   g_free (ui_path);
 
-//  ui_path = g_build_filename (PKGDATADIR, "ui", "menus.ui", NULL);
-//  gtk_builder_add_from_file (builder, ui_path, NULL);
-//  g_free (ui_path);
-
   app->mainwin = GTK_WIDGET (gtk_builder_get_object (builder, "mainwin"));
 
-  app->actions = g_hash_table_new (NULL, NULL);
-
-  menu_item = GTK_WIDGET (gtk_builder_get_object (builder, "gameNew"));
-  g_hash_table_insert (app->actions, "GameNew", menu_item);
-  g_signal_connect (menu_item, "activate", (GCallback)verb_GameNew_cb, NULL);
-
-  menu_item = GTK_WIDGET (gtk_builder_get_object (builder, "gameEnd"));
-  g_hash_table_insert (app->actions, "GameEnd", menu_item);
-  g_signal_connect (menu_item, "activate", (GCallback)verb_GameEnd_cb, NULL);
-
-  menu_item = GTK_WIDGET (gtk_builder_get_object (builder, "gameSkip"));
-  g_hash_table_insert (app->actions, "GameSkip", menu_item);
-  g_signal_connect (menu_item, "activate", (GCallback)verb_GameSkip_cb, NULL);
-
-  menu_item = GTK_WIDGET (gtk_builder_get_object (builder, "gameReset"));
-  g_hash_table_insert (app->actions, "GameReset", menu_item);
-  g_signal_connect (menu_item, "activate", (GCallback)verb_GameReset_cb, NULL);
-
-  menu_item = GTK_WIDGET (gtk_builder_get_object (builder, "gameUndo"));
-  g_hash_table_insert (app->actions, "GameUndo", menu_item);
-  g_signal_connect (menu_item, "activate", (GCallback)verb_GameUndo_cb, NULL);
-
-  menu_item = GTK_WIDGET (gtk_builder_get_object (builder, "gamePause"));
-  g_hash_table_insert (app->actions, "GamePause", menu_item);
-  g_signal_connect (menu_item, "activate", (GCallback)verb_GamePause_cb, NULL);
-
-  menu_item = GTK_WIDGET (gtk_builder_get_object (builder, "gameContinue"));
-  g_hash_table_insert (app->actions, "GameContinue", menu_item);
-  g_signal_connect (menu_item, "activate", (GCallback)verb_GameContinue_cb, NULL);
-
-  menu_item = GTK_WIDGET (gtk_builder_get_object (builder, "gameQuit"));
-  g_signal_connect (menu_item, "activate", (GCallback)verb_GameExit_cb, NULL);
-
-  menu_item = GTK_WIDGET (gtk_builder_get_object (builder, "gameAbout"));
-  g_signal_connect (menu_item, "activate", (GCallback)verb_HelpAbout_cb, NULL);
-
   g_signal_connect (G_OBJECT (app->mainwin), "delete_event",
                     (GCallback) on_app_destroy_event, app);
 
@@ -652,54 +623,60 @@ static AtomixApp *create_gui (void)
   app->lb_formula = GTK_WIDGET (gtk_builder_get_object (builder, "formula_value"));
   app->lb_score = GTK_WIDGET (gtk_builder_get_object (builder, "score_value"));
 
-  g_object_unref (builder);
-
-  icon_path = g_build_filename (DATADIR,
-							    "pixmaps",
-							    "atomix-icon.png",
-							    NULL);
-  gtk_window_set_default_icon_from_file (icon_path,
-					 		   NULL);
-  g_free (icon_path);
-
   gtk_widget_show_all (GTK_WIDGET (app->mainwin));
 
+
+  if (gtk_application_prefers_app_menu (GTK_APPLICATION (app_instance))) {
+    GMenu * menu = G_MENU (gtk_builder_get_object (builder, "app-menu"));
+    gtk_application_set_app_menu (GTK_APPLICATION (app->app_instance), G_MENU_MODEL (menu));
+//    GtkWidget *menubar = GTK_WIDGET (gtk_builder_get_object (builder, "menubar"));
+//    gtk_widget_set_visible (menubar, FALSE);
+  }
+
+  g_object_unref (builder);
+
   return app;
 }
 
+static void
+app_activate (GApplication *app_instance, gpointer user_data)
+{
+
+  if (app == NULL) {
+    /* make a few initalisations here */
+    g_action_map_add_action_entries (G_ACTION_MAP (app_instance), app_entries, G_N_ELEMENTS (app_entries), app_instance);
+
+    app = create_gui (app_instance);
+    g_action_map_add_action_entries (G_ACTION_MAP (app->mainwin), win_entries, G_N_ELEMENTS (win_entries), app_instance);
+
+    game_init ();
+    gtk_widget_set_size_request (GTK_WIDGET (app->mainwin), 678, 520);
+
+    //gtk_window_set_resizable (GTK_WINDOW (app->mainwin), FALSE);
+    gtk_widget_show (app->mainwin);
+    gtk_application_add_window (GTK_APPLICATION (app_instance), GTK_WINDOW (app->mainwin));
+  } else {
+    gtk_window_present (GTK_WINDOW (app->mainwin));
+  }
+}
+
 int main (int argc, char *argv[])
 {
-  GOptionContext *context;
-  gboolean retval;
-  GError *error = NULL;
+  GtkApplication *gtk_app;
 
-  context = g_option_context_new (NULL);
-  g_option_context_set_translation_domain (context, GETTEXT_PACKAGE);
-  g_option_context_add_group (context, gtk_get_option_group (TRUE));
-
-  retval = g_option_context_parse (context, &argc, &argv, &error);
-  g_option_context_free (context);
-  if (!retval) {
-    g_print ("%s", error->message);
-    g_error_free (error);
-    exit (1);
-  }
+  int status;
 
   g_set_application_name (_("Atomix"));
 
   bindtextdomain (GETTEXT_PACKAGE, GNOMELOCALEDIR);
   bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
   textdomain (GETTEXT_PACKAGE);
-  
-  /* make a few initalisations here */
-  app = create_gui ();
 
-  game_init ();
+  gtk_app = gtk_application_new ("org.gnome.atomix", G_APPLICATION_FLAGS_NONE);
+  g_signal_connect (gtk_app, "activate", G_CALLBACK (app_activate), NULL);
 
-  gtk_widget_set_size_request (GTK_WIDGET (app->mainwin), 678, 520);
-  //gtk_window_set_resizable (GTK_WINDOW (app->mainwin), FALSE);
-  gtk_widget_show (app->mainwin);
+  status = g_application_run (G_APPLICATION (gtk_app), argc, argv);
+  g_object_unref (gtk_app);
 
-  gtk_main ();
-  return 0;
+  return status;
 }
